@@ -2,7 +2,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-FileCopyrightText: 2024-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 from __future__ import annotations
@@ -124,7 +124,7 @@ class Session:
         subprocess.check_output(import_cert)
 
     def __enter__(self):  # -> Session # Py3.9: Self
-        yield self  # FIXME?
+        yield self  # FIXME: ?
 
     def __exit__(self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
         self.driver.quit()
@@ -419,7 +419,7 @@ else:
         client = Client(hostname=hostname, username=admin_username, password=admin_password, useragent='UCS/ucs-test')
         return client
 
-    @pytest.fixture()
+    @pytest.fixture
     def ucs_call(fqdn: str) -> Callable[[Sequence[str]], None]:
         def _run(args):
             logger.info(f'Running: {args!r}')
@@ -431,7 +431,7 @@ else:
                 subprocess.run(['ssh', fqdn] + [quote(arg) for arg in args], check=True)
         return _run
 
-    @pytest.fixture()
+    @pytest.fixture
     def ucr(umc):
         class UCR:
             def __init__(self, client) -> None:
@@ -610,7 +610,7 @@ else:
                 user.etag = user.last_modified = None
                 user.delete()
 
-    @pytest.fixture()
+    @pytest.fixture
     def new_user(users):
         """Creates a new user and cleans up"""
         user = users()
@@ -648,12 +648,12 @@ else:
             logger.warning(f'  using {ret}')
         return os.path.abspath(ret)
 
-    @pytest.fixture()
+    @pytest.fixture
     def test_logger() -> logging.Logger:
         """Our logger instance so you can print some info for pytest"""
         return logger
 
-    @pytest.fixture()
+    @pytest.fixture
     def chrome(selenium_base_url: str, selenium_screenshot_path: str) -> Iterator:
         """A running chrome instance, controllable by selenium"""
         with Session.running_chrome(selenium_base_url, selenium_screenshot_path) as c:
